@@ -30,11 +30,13 @@ import xml.parsers.expat # Needed for parsing documents
 
 def version():
 	"Get the ooolib-python version"
-	return "ooolib-python-0.0.13"
+	return "ooolib-python-0.0.16"
 
 def clean_string(data):
 	"Returns an XML friendly copy of the data string"
-	data = str(data)
+	
+	data = unicode(data) # This line thanks to Chris Ender
+	
 	data = data.replace('&', '&amp;')
 	data = data.replace("'", '&apos;')
 	data = data.replace('"', '&quot;')
@@ -616,18 +618,27 @@ class CalcSheet:
 		# Example Translations
 		# '=SUM(A1:A2)'
 		# datavalue = 'oooc:=SUM([.A1:.A2])'
+		# '=IF((A5>A4);A4;"")'
+		# datavalue = 'oooc:=IF(([.A5]&gt;[.A4]);[.A4];&quot;&quot;)'
 		data = str(data)
-		redata = re.search('^=([A-Z]+)\(([A-Z0-9:]+)\)$', data)
+		data = clean_string(data)
+		redata = re.search('^=([A-Z]+)(\(.*)$', data)
 		if redata:
+			# funct is the function name.  The rest if the string will be the functArgs
 			funct = redata.group(1)
-			parts = redata.group(2).split(':')
-			nparts = []
-			while parts:
-				part = parts.pop(0)
-				part = '.%s' % part
-				nparts.append(part)
-			parts = ':'.join(nparts)
-			data = 'oooc:=%s([%s])' % (funct, parts)
+			functArgs = redata.group(2)
+			# Search for cell lebels and replace them
+			reList = re.findall('([A-Z]+\d+)', functArgs)
+			# sort and keep track so we do not do a cell more than once
+			reList.sort()
+			lastVar = ''
+			while reList:
+				# Replace each cell label
+				curVar = reList.pop()
+				if curVar == lastVar: continue
+				lastVar = curVar
+				functArgs = functArgs.replace(curVar, '[.%s]' % curVar)
+			data = 'oooc:=%s%s' % (funct, functArgs)
 		return data
 
 	def get_name(self):
@@ -834,6 +845,7 @@ class Calc:
 		self.parser_sheet_num = 0
 		self.parser_sheet_row = 0
 		self.parser_sheet_column = 0
+		self.parser_cell_repeats = 0
 		self.parser_cell_string_pending = False
 		self.parser_cell_string_line = ""
 
@@ -977,6 +989,8 @@ class Calc:
 
 		# Okay, now keep track of the sheet cell data
 		if (self.parser_element == 'table:table-cell'):
+			# By default it will repeat zero times
+			self.parser_cell_repeats = 0
 			# We must be in a new column
 			self.parser_sheet_column += 1
 			# Set some default values
@@ -992,9 +1006,37 @@ class Calc:
 				datatype = ""
 				self.parser_cell_string_pending = True
 				self.parser_cell_string_line = ""
+			if 'table:number-columns-repeated' in attrs:
+				self.parser_cell_repeats = int(attrs['table:number-columns-repeated']) - 1
 			# Set the cell value
 			if datatype:
-				self.set_cell_value(self.parser_sheet_column, self.parser_sheet_row, datatype, value)
+				# I should do this once per cell repeat above 0
+				for i in range(0, self.parser_cell_repeats+1):
+					self.set_cell_value(self.parser_sheet_column+i, self.parser_sheet_row, datatype, value)
+
+		# There are lots of interesting cases with table:table-cell data.  One problem is
+		# reading the number of embedded spaces correctly.  This code should help us get
+		# the number of spaces out.
+
+		if (self.parser_element == 'text:s'):
+			# This means we have a number of spaces
+			count_num = 0
+			if 'text:c' in attrs:
+				count_alpha = attrs['text:c']
+				if (count_alpha.isdigit()):
+					count_num = int(count_alpha)
+			# I am not sure what to do if we do not have a string pending
+			if (self.parser_cell_string_pending == True):
+				# Append the currect number of spaces to the end
+				self.parser_cell_string_line = "%s%s" % (self.parser_cell_string_line, ' '*count_num)
+
+		if (self.parser_element == 'text:tab-stop'):
+			if (self.parser_cell_string_pending == True):
+				self.parser_cell_string_line = "%s\t" % (self.parser_cell_string_line)
+
+		if (self.parser_element == 'text:line-break'):
+			if (self.parser_cell_string_pending == True):
+				self.parser_cell_string_line = "%s\n" % (self.parser_cell_string_line)
 
 		# Debugging statements
 		if self.debug: print "  List: ", self.parser_element_list
@@ -1012,6 +1054,9 @@ class Calc:
 			if (self.parser_cell_string_pending):
 				self.parser_cell_string_pending = False
 
+		# Take care of repeated cells
+		if (self.parser_element == 'table:table-cell'):
+			self.parser_sheet_column += self.parser_cell_repeats
 
 		# Readjust parser_element_list and parser_element
 		if (self.parser_element_list):
@@ -1022,14 +1067,18 @@ class Calc:
 	def parse_content_char_data(self, data):
 		if self.debug: print "  Character data: ", repr(data)
 
-		if (self.parser_element == 'text:p'):
+		if (self.parser_element == 'text:p' or self.parser_element == 'text:span'):
 			if (self.parser_cell_string_pending):
 				# Set the string and leave string pending mode
 				# This does feel a little kludgy, but it does the job
 				self.parser_cell_string_line = "%s%s" % (self.parser_cell_string_line, data)
-				self.set_cell_value(self.parser_sheet_column, self.parser_sheet_row,
+
+				# I should do this once per cell repeat above 0
+				for i in range(0, self.parser_cell_repeats+1):
+					self.set_cell_value(self.parser_sheet_column+i, self.parser_sheet_row,
 						    'string', self.parser_cell_string_line)
 
+
 	def content_parse(self, data):
 		"Parse Content Data from a content.xml file"
 
@@ -1074,6 +1123,9 @@ class Calc:
 	def _zip_insert(self, file, filename, data):
 		"Insert a file into the zip archive"
 
+		# zip seems to struggle with non-ascii characters
+		data = data.encode('utf-8')
+
 		now = time.localtime(time.time())[:6]
 		info = zipfile.ZipInfo(filename)
 		info.date_time = now
